//
// This file is part of the FLTK Imago project
// Copyright (C) 2002-2005 Chris Osgood
// http://imago.functionalfuture.com
//
// "$Id: Fl_SVG_Button.H 46 2005-01-04 04:09:52Z chris $"
//
// SVG button header file for the Fast Light Tool Kit (FLTK).
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//
// Please report all bugs and problems to "imago at functionalfuture.com"
//

#ifndef Fl_SVG_Button_H
#define Fl_SVG_Button_H

#include <FL/Fl_Button.H>
#include "Fl_SVG_Image.H"

#ifndef IMAGO_EXPORT
#define IMAGO_EXPORT
#endif

class Fl_SVG_Button : public Fl_Button
{
private:
   Fl_SVG_Image* up_image_;         // Normal button image (required)
   Fl_SVG_Image* down_image_;       // "Pressed" image (optional)
   Fl_SVG_Image* focus_image_;      // Widget has focus (optional)
   Fl_SVG_Image* highlight_image_;  // Mouse is over widget (optional)
   bool focus_highlight_;

public:
   IMAGO_EXPORT Fl_SVG_Button(int X, int Y, int W, int H, const char* label = 0);
   IMAGO_EXPORT virtual ~Fl_SVG_Button();

   IMAGO_EXPORT virtual int handle(int);
   IMAGO_EXPORT void up_image(Fl_SVG_Image* img);
   IMAGO_EXPORT void down_image(Fl_SVG_Image* img);
   IMAGO_EXPORT void focus_image(Fl_SVG_Image* img);
   IMAGO_EXPORT void highlight_image(Fl_SVG_Image* img);
   IMAGO_EXPORT const Fl_SVG_Image* image() const { return up_image_; }
   IMAGO_EXPORT const Fl_SVG_Image* down_image() const { return down_image_; }
   IMAGO_EXPORT const Fl_SVG_Image* focus_image() const { return focus_image_; }
   IMAGO_EXPORT const Fl_SVG_Image* highlight_image() const { return highlight_image_; }

protected:
   IMAGO_EXPORT virtual void draw();
};

#endif // Fl_SVG_Button_H
