//
// This file is part of the FLTK Imago project
// Copyright (C) 2002-2005 Chris Osgood
// http://imago.functionalfuture.com
//
// "$Id: Fl_SVG_Image.H 66 2005-01-11 02:46:14Z chris $"
//
// SVG image header file for the Fast Light Tool Kit (FLTK).
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//
// Please report all bugs and problems to "imago at functionalfuture.com"
//

#ifndef Fl_SVG_Image_H
#define Fl_SVG_Image_H

#include <FL/Fl_Image.H>
#include <stdlib.h>

#ifndef IMAGO_EXPORT
#define IMAGO_EXPORT
#endif

class Fl_SVG_Image : public Fl_RGB_Image
{
private:
   void* svgcontext_; // SVG-Cairo context
   int pt_width_;     // Image width in "points" (actual size from SVG file)
   int pt_height_;    // Image height in "points" (actual size from SVG file)
   int draw_width_;   // Width image was drawn at
   int draw_height_;  // Height image was drawn at
   Fl_Color bgcolor_; // Background color (for blending translucent areas of image)
   Fl_Color draw_bg_; // Background color that was last drawn

public:
   IMAGO_EXPORT Fl_SVG_Image(const char* bits, size_t len, int W=0, int H=0, Fl_Color c = FL_BACKGROUND_COLOR);
   IMAGO_EXPORT Fl_SVG_Image(const char* filename, int W=0, int H=0, Fl_Color c = FL_BACKGROUND_COLOR);
   IMAGO_EXPORT virtual ~Fl_SVG_Image();

   IMAGO_EXPORT int pt_width() const { return pt_width_; }
   IMAGO_EXPORT int pt_height() const { return pt_height_; }
   IMAGO_EXPORT void size(int W, int H) { w(W); h(H); }
   IMAGO_EXPORT void bgcolor(Fl_Color c) { bgcolor_ = c; }
   IMAGO_EXPORT void destroy();
   IMAGO_EXPORT int svgdata(const char* data, size_t len);
   IMAGO_EXPORT virtual void draw(int XP, int YP, int WP, int HP, int cx, int cy);
   IMAGO_EXPORT bool hit(int at_x, int at_y, int thresh = 1);

protected:
   static char* Fl_SVG_Image::decompGZ(const char* in, size_t size);
};

#endif // Fl_SVG_Image_H
